#import "@preview/touying:0.6.1": *
#import "tomSlides.typ": *

// need to expose the fill here.
#let mybox(content, fill: none, _center: false) = {
  let box = box(
    radius: .3cm,
    inset: .7em,
    fill: fill,
    stroke: 1pt,
  )[#align(left)[#content]]
  if _center {
    align(center)[#box]
  } else {
    box
  }
}

// Positional arguments go first.
#let gruenbox(content, center: false) = mybox(
  content,
  fill: rgb("#c8fcbf"),
  _center: center
)

#let orangebox(content, center: false) = mybox(
  content,
  fill: rgb("#fecd72"),
  _center: center
)

#let redbox(content, center: false) = mybox(
  content,
  fill: rgb("#ffc1c1"),
  _center: center
)

#let graubox(content, center: false) = mybox(
  content,
  fill: rgb("#f2f2f2"),
  _center: center
)

#let theorembox(content, center: false) = redbox(
  [*Theorem.*#h(.4em) #content],
  center: center
)

#let defbox(content, center: false) = orangebox(
  [*Definition.*#h(.4em) #content],
  center: center
)


#show: tom-theme.with(
  aspect-ratio: "16-9",
  align: horizon,
  config-common(handout: true),
  config-info(
    title: [Efficiently deciding if an ideal is toric after a linear coordinate change],
    subtitle: [],
    author: [#underline[Thomas Kahle] and Julian Vill],
    date: [June 2, 2025],
    institution: [Otto-von-Guericke-Universität Magdeburg],
    logo: {},
  ),
)

#set text(
  size: 22pt
)

#title-slide()

#slide()[
  #defbox(center:true)[
    A prime ideal $I subset k[x_1,...,x_n]$ is *toric* if it can be generated by pure differences of monomials:
    $
      I = angle.l x^u - x^v | u,v in NN^n angle.r 
    $ 
  ] #pause
  #redbox(center:true)[
    *Question:* Given a prime ideal $I subset k[x_1,...,x_n]$, does there exist a linear coordinate change $g in "GL"_n (k)$ such that $g.I$ is toric?

    - Is this decidable on a Turing machine?
    - Can such a $g$ be computed?  Efficiently? 
  ]
]

== Why?
#slide[
  #orangebox(center:false)[
    - *Sparse equations are better than dense equations.* #pause
      - Is $I$ generated by binomials?
      - Does $I$ contain a binomial?
      - Is $I$ generated by binomials after linear coordinate change?
      - Does $I$ contain a binomial after a linear coordinate change?
      - Does $I$ contain a polynomial with at most $t$ terms?
    #pause
    - *Toric ideals are nice* #pause
      - Make interesting varieties but with combinatorial theory.
      - Gröbner bases of toric ideals are polyhedral objects.
      - Toric varieties appear in applications, e.g. discrete exponential families. #pause
    - *Any new tool allows new larger scale experiments*.
  ]
]

== Examples of hidden toric structure
#slide()[
  #gruenbox(center:false)[
    - Group based models in phylogenetics become toric in Fourier coordinates
    - Cumulant coordinates in statistics can dramatically shorten polynomials
      - E.g. the tangential variety to Segre becomes toric (non-linear, though)
    - Chemical reaction network theory: toric steady states
  ]
]

#slide()[
  #set page(header:none)
  #align(center)[#image("mo.png", height: 110%)]
]

// Abstract to own boxes with own colors!

== No toric structure: Lisa Nicklasson's example
#slide[
  #orangebox(center:true)[
        Are all discrete Bayesian networks toric after linear coordinate changes?
      ]
  #pause
  #v(-.5em)
  #grid(
    columns: (1fr, auto),
    column-gutter: 3pt,
    gruenbox[
      Consider the prime ideal generated by
      $
        mat(delim: "|",
          p_1111 + p_1112 + p_1121 + p_1122, p_1211 + p_1212 + p_1221 + p_1222;
          p_2111 + p_2112 + p_2121 + p_2122, p_2211 + p_2212 + p_2221 + p_2222
        )
      $
      and
      $
        mat(delim: "|",
          p_1111, p_2111;
          p_1112, p_2112
        ),
        mat(delim: "|",
          p_1121, p_2121;
          p_1122, p_2122
        ),
        mat(delim: "|",
          p_1211, p_2211;
          p_1212, p_2212
        ),
        mat(delim: "|",
          p_1221, p_2221;
          p_1222, p_2222
        )
      $
      ],
    image("bn.png", width:6cm)
  )
  #v(-.5em)
  #theorembox[
    No linear coordinate change makes this toric.
  ]
]

#slide[
  #align(center)[
    #image("kmm.png", width: 60%)
  ]
  #orangebox[
    - The locus in $"GL"_n (k)$ which makes an ideal binomial is constructible.
    - Can in principle be computed using comprehensive Gröbner bases.
    - Solves a much more general problem.
    - Not efficient enough for above examples.
  ]
  #align(right)[
    Goal: Make it efficient in more specific situation.
  ]
]

== Approach

#slide[
  #set align(center)
  #orangebox()[
    #set align(center)
    A variety is toric if it is the closure of a torus orbit of one point.\ 
  Find the maximal torus acting on $V (I)$ in $"GL"_n$!
  ]

  #v(2cm)
  #graubox()[
    Here _torus_ always means algebraic torus, i.e. a commutative group (of matrices) that is isomorphic to $(CC^*)^k$, e.g. a group of diagonal matrices.
  ]
]

== Example
#slide[
  #gruenbox(center:true)[
    - Let $I = angle.l x z - y^2 angle.r in CC[x,y,z]$.  Its variety is toric.
    - A $2d$-algebraic torus acting on it is generated by the matrices
      $
        mat(
          a, 0, 0;
          0, 1, 0;
          0, 0, a^(-1)
        ) quad
        mat(
          1, 0, 0;
          0, b, 0;
          0, 0, b^2
        ), quad a,b in CC^*
      $
    - $V(x z - y^2)$ is the closure of the orbit of $(1,1,1)$ under the action of $(CC^*)^2$.
    - The torus is a (diagonal) subgroup of $"GL"_3(CC)$ and thus easy to find.
    - Necessarily this torus must be a subgroup of the subgroup fixing the ideal $I$!
  ]
  
  #graubox(center:true)[
    - Also $V( (x+y)z-y^2 )$ is a toric variety (obvious?).
    - There is some $2d$ (non-diagonal) algebraic torus in the group fixing this ideal.
    - Find it! Diagonalize it!
  ]
]

== Setup
#slide[
  #orangebox(center:true)[
    - Fix $k = CC$, but in reality, start with $QQ$ and algebraically extend as needed.
    - $I subset CC[x_1,...,x_n]$ is assumed prime and homogeneous.
    - The Lie group $"GL"_n (CC)$ acts on the polynomial ring via
      $
        g.f(x) = f compose g^(-1) (x) = f(g^(-1) dot x)
      $
    - Consider the stabilizer of $I$:
      $
        G_I := {g in "GL"_n (CC) | g.I subset I}
      $
      This is itself a Lie group (like any closed subgroup of $"GL"_n (CC)$).
    - Lie algebra $frak(g)_I$ of $G_I$ can be computed from $I$ using linear algebra.
  ]
]

== Symmetry Lie algebras (Maraj and Pal, arXiv:2309.10741)
#slide[
  #orangebox(center:true)[
    - The Lie algebra $frak(g)_I$ can be computed as the stabilizer of an action $ast$:
      - $g ast c = 0$ for $c in CC$
      - $g ast x_i = g dot x_i$
      - $g ast (p q) = (g ast p) q + p (g ast q)$ for all $p,q in CC[x_1,...,x_n]$
    - Then $frak(g)_I = {g in CC^(n times n) | g ast I subset I}$
    - Question 34: Can symmetry Lie algebras detect if $I$ is toric?
  ]

  #redbox(center:true)[
    *[MP23] criterion:*
    If $dim(G_I) = dim(frak(g)_I) < dim(I)$ then $V(I)$ is not toric.
  ]

  #gruenbox(center:true)[
    This solves Lisa Nicklasson's example again because there $dim(frak(g)_I) = 8$\
    (but $5$ equations in $16$ variables).
  ]
]

== Our plan for Question 34 
#slide[
  #orangebox(center:true)[
    - If $I$ is prime and $I' = g.I$ is binomial, there is a maximal torus $T'$ in $G_I$ such that the orbit of a generic point in $V(I)$ is dense in $V(I)$. #pause
    - Can compute _some_ maximal torus $T$ in $G_I$ (or corresponding algebra in $frak(g)_I$) using Lie theory and Cartan algebras.
    - All maximal tori are conjugate, so $T$ and $T'$ are. Thus the orbit of a generic point of $V(I)$ under $T$ is also dense. #pause
    - To find the coordinate transform, we diagonalize the torus. Then it acts as
      $
        ((t_1,...,t_d),(x_1,...,x_n)) -> (t^a_1 x_1, ... t^a_n x_n)
      $
      for some $a_1,...,a_n in ZZ^d$.
  ]
]

== Computing a maximal torus
#slide[
  #orangebox(center:true)[
    - We compute a nilpotent and self-normalizing (Cartan) subalgebra $frak(c)$.
    - Its Lie group is the centralizer of a maximal torus and of the form $T times C$ with $T$ a maximal torus and $C$ unipotent.
    - Any Cartan subgalgebra $frak(c)$ decomposes as $frak(t) plus.circle frak(n)$ where $frak(t)$
      consists of diagonalizable and $n$ of nilpotent matrices.
    - All elements of $frak(t)$ commute and are thus simultaneously diagonalizable.
    - We can diagonalize the toral subalgebra $frak(t)$ by Jordan decomposition of a generic element of $frak(c)$.
  ]
]

== The algorithm
#slide[
  #orangebox(center:true)[
    + Compute the Lie algebra $frak(g)_I$.
    + Pick $x in frak(g)_I$ randomly and compute $frak(c) = ker("ad"(x)^(dim frak(g)_I))$.
    + Check if $frak(c)$ is Cartan, otherwise try again with new $x$.
    + Decompose $frak(c) = frak(t) plus.circle frak(n)$.
    + Diagonalize $frak(t)$ with a suitable $S in "GL"_n (CC)$.
    + Check if $S.I$ is binomial (or toric).
  ]

  #orangebox(center:true)[
    *Note:*
    If $V(I)$ is not binomial, then the last step must return FALSE.
  ]

  #graubox(center:true)[
    The algorithm is implemented in #smallcaps[sage] and runs on relevant examples.
  ]
]

// Maybe show the actual code here?
== Back to mathoverflow...
#slide[
#set text(size: 15pt)
#set align(center)
```python
┌────────────────────────────────────────────────────────────────────┐
│ SageMath version 10.6, Release Date: 2025-03-31                    │
│ Using Python 3.12.5. Type "help()" for help.                       │
└────────────────────────────────────────────────────────────────────┘
sage: load ("isToric.sage")
....: R.<e,t,r,y,q,u,w,o> = PolynomialRing(QQ)
....: I = ideal (e*t-r*y-q*u+w*o, w*t-q*y-r*u+e*o, w*e-q*r-y*u+t*o)
....: ideal_is_toric(I)
[##############################] 100%
searching torus
diagonalizing torus
diagonalizing ideal
checking if ideal is binomial and prime after the coordinate change
[
      [ 1  1  1  1  1  1  1  1]
      [-1  1 -1  1  1 -1  1 -1]
      [ 1  1 -1 -1  1  1 -1 -1]
      [-1  1  1 -1  1 -1 -1  1]
      [-1  1 -1  1 -1  1 -1  1]
      [ 1  1  1  1 -1 -1 -1 -1]
      [-1  1  1 -1 -1  1  1 -1]
True, [ 1  1 -1 -1 -1 -1  1  1]
]
```
]

// Drawing a block matrix: https://github.com/typst/typst/discussions/5207  ?
// Rather use augment! https://typst.app/docs/reference/math/mat/
// 
== Non-homogeneous ideals are in reach
#slide[
  #orangebox(center:true)[
    If $I$ is not homogeneous, just test its homogenization $I^h$!
    - We look for affine linear coordinate changes.
    - Consider the set of matrices fixing the homogenization variable, i.e.
      $
        S = mat(
          1, 0, dots.h.c, 0;
          star, , , ;
          dots.v, , star, ;
          star, , ,;
          augment: #(hline: 1, vline: 1)
        )
      $
    - Do all computations in the Lie algebra of $(n+1)$-matrices that have $e_0$ as a left eigenvector.
  ]
]

== Non-reduced schemes are out of reach
#slide[
  #gruenbox(center:true)[
    - Consider the zero-dimensional(!) binomial ideal $I = angle.l x^4, y^4, x^3 y - x y^3 angle.r$
    - The Lie algebra $frak(g)_I$ consists only of multiples of the identity.
    - Applying a linear coordinate change does not change anything about this.
    - Thus we will never find the binomial structure using symmetry Lie algebras.
  ]

  #orangebox(center:true)[
    We just don't understand binomial schemes very well!
  ]
]

== Experiments: Toric Gaußian graphical models
#slide[
  #orangebox(center:true)[
    - Let $G$ be an undirected graph with edge set $E$.
    - Gaußian graphical model:
      $
        M_G = {Sigma in "PD"_n : Sigma^(-1)_(i j) = 0 " for " i j in.not E}
      $
    - When is (the closure of) $M$ a toric variety?
    - Challenge: We don't know many vanishing ideals of $M_G$.
    - Misra/Sullivant: gen. deg. $<= 2$ $=>$ toric (in original coordinates).
  ]
]

#slide[
  #gruenbox(center:true)[
    #strong[All graphs on 4 vertices:]
    - Computations in 10 variables.
    - All vanishing ideals can be computed.
    - Exactly those which are toric in original coordinates are toric.
    - Lie algebras are usually large, live in $"GL"_10 (CC)$ now.

    #table(
      columns: 5,
      align: center,
      table.header[*graph*][*dim model*][*dim Lie algebra*][*dim max tori*][*(can be made) toric*],
      [*diamond*], [9], [30], [6], [no],
      [*paw*], [8], [52], [8], [yes],
      [*cycle*], [8], [4], [4], [no],
      [*claw*], [7], [37], [7], [yes],
      [*path*], [7], [33], [7], [yes],
    )
  ]
]

#slide[
  #gruenbox(center:true)[
    #strong[5, 6, 7 vertices:]
    - Computations in 15 / 21 / 28 variables still mostly doable.
    - From 6 vertices on, hardly any vanishing ideals known.
    - Use CI ideal?
      - This computes a maximal torus acting on one component.
      - But no simple way to compute dimension of orbits or stabilizers.
    - No example of an ideal that is toric after coordinate change but not before.
  ]
]

== Outlook
#slide[
  #gruenbox(center:true)[
    - The algorithm always computes a maximal torus acting on $V(I)$.
    - Study special cases, e.g. group $G_I$ is a torus, base change is unique.
    - Looking for more examples.
    - What to do with knowledge about low-codimension tori acting on varieties?
    - Code available at *#link("https://github.com/villjulian/isToric")[https://github.com/villjulian/isToric]*.
  ]
  #pause

  #v(1em)
  #align(right)[
    Thanks for listening!
  ]
]








